@@ -47,12 +47,27 @@ class Redis:
     def get(self, key: str) -> str | None:
         return self.redis_client.get(self.prefixed(key))  # type: ignore
 
+    def getset(self, key: str, value: str) -> str | None:
+        return self.redis_client.getset(self.prefixed(key), value)  # type: ignore
+
     def set(self, key: str, value: str, ex=None, px=None, nx=False) -> bool:
         return self.redis_client.set(self.prefixed(key), value, ex=ex, px=px, nx=nx)  # type: ignore
 
+    def setnx(self, key: str, value: str) -> bool:
+        return self.redis_client.setnx(self.prefixed(key), value)  # type: ignore
+
+    def setex(self, key: str, time: int, value: str) -> bool:
+        return self.redis_client.setex(self.prefixed(key), time, value)  # type: ignore
+
     def delete(self, key: str) -> int:
         return self.redis_client.delete(self.prefixed(key))  # type: ignore
 
+    def expire(self, key: str, time: int) -> bool:
+        return self.redis_client.expire(self.prefixed(key), time)  # type: ignore
+
+    def exists(self, key: str) -> int:
+        return self.redis_client.exists(self.prefixed(key))  # type: ignore
+
     def incr(self, key: str, amount=1) -> int:
         return self.redis_client.incr(self.prefixed(key), amount)  # type: ignore
 
